import {request} from "./request";

interface Code {
  image: string
}

interface Login {
  access_token: string
  code?: Code
  company: Company
  token: string
  user: User
  catch_key: string
}

interface CheckoutBody {
  catch_key: string
  code: string
  phone_number: string
}

interface CheckoutData {
  token: string
  phone_number: string
  user: User
  company: Company
}

interface DepListData {
  departments: Department[]
  user: User
}

interface LearningRecord {
  user_course_records: LearnRecord[]
}


export const userApi = {
  login(code: string) {
    return request<Login>('/api/v1/auth/login/wechat', 'POST', {code})
  },
  checkout(data: CheckoutBody) {
    return request<CheckoutData>('/api/v1/auth/login/checkout', 'POST', data)
  },
  unbind(id: number) {
    return request(`/api/v1/auth/login/unbind/${id}`, "PUT")
  },
  putName(id: number, name: string) {
    return request<User>(`/api/v1/auth/login/${id}`, "PUT", {name})
  },
  /** 所属部门 */
  depList() {
    return request<DepListData>(`/api/v1/user/detail`, "GET")
  },
  code(catch_key: string) {
    return request<{ code: Code }>(`/api/v1/auth/login/code`, "POST", {openid: catch_key})
  },
  learningRecord(courseId = 0) {
    return request<LearningRecord>(`/api/v1/user/record/course`, "GET", {courseId})
  }
}
