import {FC, useEffect, useState} from "react";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import {View} from "@tarojs/components";
import {Profile} from '@/store'
import {CourseDepData} from "@/api";
import Collapse from "@/components/collapse/collapse";
import Hours from "@/pages/business/videoInfo/components/hours";

interface Props {
  data: CourseDepData | null
  setPlayId: (id: number) => void
}

const Catalogue: FC<Props> = ({data, setPlayId}: Props) => {
  const {user} = Profile.useContainer()
  const [current, setCurrent] = useState(0)
  const [tabList, setTabList] = useState<TabList[]>([
    {title: '介绍', value: 0},
    {title: '目录', value: 1},
    // {title: '评价', value: 2},
  ])

  useEffect(() => {
    if (user?.role_type && user?.role_type > 0) {
      setTabList([
        ...tabList,
        // {title: '部门进度', value: 3}
      ])
    }
  }, [])

  function tabChange({tab}: OnChangOpt) {
    setCurrent(tab?.value as number)
  }

  function getHors(chapter_id: number): Hour[] | null {
    for (const d of Object.values(data?.hours || {})) {
      if (d[0].chapter_id === chapter_id) {
        return d
      }
    }
    return null
  }

  function complete(id: number): boolean {
    return !!data?.learn_hour_records?.[id]?.is_finished
  }

  return (
    <View className='catalogue'>
      <Tabs tabList={tabList} onChange={tabChange} current={current}/>
      <View className='py-2'>
        {current === 0 && <View className='short_desc'>{data?.course.short_desc || '无'}</View>}
        {current === 1 && <View>
          <View className='font-weight mb-2'>课程目录</View>
          {data?.chapters.length ? Object.values(data?.chapters || {}).map((d, index) => <View>
              <Collapse title={`${index + 1}.${d.name}`}>
                <>
                  {getHors(d.id)?.map((hor, index) => <Hours
                      id={hor.id}
                      index={index}
                      title={hor.title}
                      duration={hor.duration}
                      complete={complete}
                      click={() => setPlayId(d.id)}
                    />
                  )}
                </>
              </Collapse>
            </View>)
            : data?.hours?.[0].map((hor, index) => <Hours
                id={hor.id}
                index={index}
                title={hor.title}
                duration={hor.duration}
                complete={complete}
                click={() => setPlayId(hor.id)}
              />
            )}
        </View>}
        {current === 2 && <View className='text-center'>评论暂未开放</View>}
      </View>
    </View>
  )
}

export default Catalogue
