import {CustomWrapper, PageContainer, ScrollView} from "@tarojs/components";
import {FC, useEffect, useState} from "react";
import HVideo from "@/components/video/video";
import {curriculum, HourPlayData} from "@/api";
import {Profile} from '@/store'
import Taro from "@tarojs/taro";

interface Props {
  id: number,
  courseId: number
  preview?: boolean
  curEnd: () => void
}

const Course: FC<Props> = ({id, courseId, preview, curEnd}: Props) => {
  const [breakpoint, setBreakpoint] = useState<any[]>([])
  const [show, setShow] = useState(false)
  const [data, setData] = useState<HourPlayData | null>(null)

  async function onEnded() {
    try {
      await curriculum.curEnd(courseId, id, data?.duration!)
      Taro.showModal({
        title: "学习完成",
        success() {
          curEnd()
        }
      })
    } catch (e) {
    }
  }

  function onBreakpoint(id: number) {
    setBreakpoint(breakpoint.filter(d => d.id != id))
    setShow(true)
  }

  async function getData() {
    const res = await curriculum.hourPlay(courseId, id)
    if (res) {
      setData(res)
    }
  }

  useEffect(() => {
    getData()
  }, [id])

  return (
    <CustomWrapper>
      <Profile.Provider>
        {data && <HVideo
          duration={data?.duration}
          preview={!!preview}
          src={data?.url || ''}
          onEnded={onEnded}
          breakpoint={breakpoint}
          onBreakpoint={onBreakpoint}
        />}

        <view>
          <PageContainer
            show={show}
            position='bottom'
            round
          >
            <ScrollView
              style='height:70vh'
              scrollY
              scrollTop={0}
              scrollWithAnimation
            >
            </ScrollView>
          </PageContainer>
        </view>
      </Profile.Provider>
    </CustomWrapper>
  )
}
export default Course
